Base Class
==========


.. currentmodule:: heatgraphy.base
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    WhiteBoard
    ClusterBoard
    LegendMaker

Layout Engine
-------------

.. currentmodule:: heatgraphy.layout
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    CrossLayout
    CompositeCrossLayout


Data Manipulation
-----------------

.. currentmodule:: heatgraphy
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Deformation

Render plan
-----------

.. currentmodule:: heatgraphy.plotter.base
.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    RenderPlan